summaryrefslogtreecommitdiff
path: root/src/core
diff options
context:
space:
mode:
Diffstat (limited to 'src/core')
-rw-r--r--src/core/common/Rtti.cpp10
1 files changed, 9 insertions, 1 deletions
diff --git a/src/core/common/Rtti.cpp b/src/core/common/Rtti.cpp
index 0443a8d..5de2b4c 100644
--- a/src/core/common/Rtti.cpp
+++ b/src/core/common/Rtti.cpp
@@ -53,13 +53,19 @@ void RttiBase::initialize() const
if (!initialized) {
initialized = true;
// Insert the parent types of the parent types
{
std::unordered_set<const RttiBase *> origParents = parents;
for (const RttiBase *parent : origParents) {
parent->initialize();
parents.insert(parent->parents.begin(), parent->parents.end());
}
+ for (const RttiBase *parent : parents) {
+ parent->initialize();
+ aggregatedTypes.insert(parent->aggregatedTypes.begin(),
+ parent->aggregatedTypes.end());
+ }
parents.insert(this);
}
@@ -71,6 +77,8 @@ void RttiBase::initialize() const
aggregatedType->initialize();
aggregatedTypes.insert(aggregatedType->aggregatedTypes.begin(),
aggregatedType->aggregatedTypes.end());
+ aggregatedTypes.insert(aggregatedType->parents.begin(),
+ aggregatedType->parents.end());
}
}
}
@@ -53,13 +53,19 @@ void RttiBase::initialize() const
if (!initialized) {
initialized = true;
- // Insert the parent types of the parent types
+ // Insert the parent types of the parent types and the aggregated types
+ // if the parents
{
std::unordered_set<const RttiBase *> origParents = parents;